@@ -448,12 +448,16 @@ class AsymptoticCLs(AnalysisObject):
         self.stdout.info('')
         
     def save(self, filename:str='limits.json', summary=True):
-        json.dump(self.limits, open(filename, 'w'), indent=2)
+        with open(filename, "w") as file:
+            json.dump(self.limits, file, indent=2)
+            file.truncate()
         if summary:
             data = {k:{kk:vv for kk,vv in self.summary[k].items() if kk not in ['nll', 'dataset']} \
                     for k,v in self.summary.items()}
             summary_filename = os.path.splitext(filename)[0]+'_summary'+os.path.splitext(filename)[1]
-            json.dump(data, open(summary_filename, 'w'), indent=2)
+            with open(summary_filename, "w") as file:
+                json.dump(data, file, indent=2)
+                file.truncate()
         
     def evaluate_limit_band(self, n:int, med_limit:float):
         init_target_cls = self.LimitTool.getTargetCLs()
