@@ -32,8 +32,11 @@ class XMLWSModifier(XMLWSBase):
     
     def __init__(self, source:Union[str, Dict], basedir:Optional[str]=None,
                  minimizer_config:Optional[Dict]=None,
+                 unlimited_stack:bool=True,
                  verbosity:Optional[Union[int, str]]="INFO"):
-        super().__init__(source=source, basedir=basedir, verbosity=verbosity)
+        super().__init__(source=source, basedir=basedir,
+                         unlimited_stack=unlimited_stack,
+                         verbosity=verbosity)
         self.minimizer_config = minimizer_config
         self.load_extension()
         self.initialize(source=source)
@@ -70,7 +73,7 @@ class XMLWSModifier(XMLWSBase):
             if (quickstats.root_version < (6, 26, 0)):
                 raise RuntimeError("\"add product terms\" is only supported after ROOT 6.26")
             
-    def parse_config_dict(self, source:str):
+    def parse_config_dict(self, source:Dict):
         _actions = source.pop("actions", {})
         config = {
             "input_file"         : source.pop("input_file"),
@@ -237,24 +240,6 @@ class XMLWSModifier(XMLWSBase):
             'file': filename
         }
         return result
-        
-    @staticmethod
-    def _get_object_name_and_type_from_expr(expr:str):
-        if ("::" in expr) and ("(" in expr):
-            object_type = WSObjectType.FUNCTION
-            object_name = expr.split("::")[1].split("(")[0]
-        elif ("(" in expr):
-            object_type = WSObjectType.CONSTRAINT
-            object_name = expr.split("(")[0]
-        elif ("[" in expr):
-            object_type = WSObjectType.VARIABLE
-            object_name = expr.split("[")[0]
-        elif (":" in expr) and not ("::" in expr):
-            raise RuntimeError(f"syntax error for the expression `{expr}`: missing colon pair")
-        else:
-            object_type = WSObjectType.DEFINED
-            object_name = expr
-        return object_name, object_type
     
     def sanity_check(self):
         if self.config is None:
