@@ -224,7 +224,7 @@ class ParamParser:
                 value = str_encode_value(round(value, 8))
             encoded_str = f"{param}_{value}"
             encoded_str_list.append(encoded_str)
-        return "_".join(encoded_str_list)
+        return "_".join(sorted(encoded_str_list))
 
     def get_external_param_points(self, dirname:str="",
                                   filter_expr:Optional[str]=None,
