@@ -91,7 +91,6 @@ def json_load(fp, *args, **kwargs):
         raise RuntimeError(f"broken json input: {fp}")
     return data
 
-
 def parse_config(source:Optional[Union[Dict, str]]=None):
     if source is None:
         return {}
@@ -194,16 +193,17 @@ def remove_list_duplicates(seq:List, keep_order:bool=True):
     else:
         return list(set(seq))
     
-def format_delimiter_enclosed_text(text:str, delimiter:str, width:int=10):
+def format_delimiter_enclosed_text(text:str, delimiter:str, width:int=10, indent_str:str="\t",
+                                   upper_margin:int=1, lower_margin:int=1):
     full_line_width = 2 * width + ( len(text) if (len(text) > 2 * width) else (2 * width) ) + 2
     full_line = delimiter * full_line_width
     line = delimiter * width
-    result = f"\n\t {full_line}\n"
+    result = "\n"*upper_margin + f"{indent_str} {full_line}\n"
     if len(text) > 2 * width:
-        result += f"\t {line} {text} {line}\n"
+        result += f"{indent_str} {line} {text} {line}\n"
     else:
-        result += f"\t {line}{text.center(2*width+2)}{line}\n"
-    result += f"\t {full_line}\n"
+        result += f"{indent_str} {line}{text.center(2*width+2)}{line}\n"
+    result += f"{indent_str} {full_line}" + "\n"*lower_margin
     return result
         
 
@@ -218,4 +218,8 @@ def filter_by_wildcards(targets:List, conditions:Optional[Union[str, List]]=None
             selected.append(target)
     if exclusion:
         return [target for target in targets if target not in selected]
-    return selected
\ No newline at end of file
+    return selected
+
+def set_unlimited_stacksize():
+    import resource
+    resource.setrlimit(resource.RLIMIT_STACK, (resource.RLIM_INFINITY, resource.RLIM_INFINITY))
\ No newline at end of file
